@@ -23,9 +23,10 @@ def build_parser():
     parser.add_argument('-q', '--quiet', action='store_true',
                         help='Do not print output to STDOUT.')
     parser.add_argument('glob_or_content', metavar='GLOB_OR_CONTENT',
+                        nargs='*',
                         help='Glob to markdown input files or markdown'
-                             ' content as a string. If not provided,'
-                             ' will be read from STDIN.')
+                             ' content as string. If not provided, will be'
+                             ' read from STDIN.')
     parser.add_argument('-i', '--ignore', dest='ignore', default=[],
                         help='List of filepaths to ignore if'
                              ' ``GLOB_OR_CONTENT`` argument is a glob,'
@@ -83,6 +84,13 @@ def build_parser():
                         help='Include mdpo specification x-headers.'
                              ' These only will be included if you do not pass'
                              ' the parameter ``--plaintext``.')
+    parser.add_argument('-c', '--include-codeblocks',
+                        dest='include_codeblocks', action='store_true',
+                        help='Include all code blocks found inside pofile'
+                             ' result. This is useful if you want to translate'
+                             ' all your blocks of code. Equivalent to append'
+                             ' \'<!-- mdpo-include-codeblock -->\' command'
+                             ' before each code block.')
     return parser
 
 
@@ -95,6 +103,8 @@ def parse_options(args=[]):
 
     if not sys.stdin.isatty():
         opts.glob_or_content = sys.stdin.read().strip('\n')
+    elif isinstance(opts.glob_or_content, list):
+        opts.glob_or_content = opts.glob_or_content[0]
     if opts.ignore:
         opts.ignore = parse_list_argument(opts.ignore)
     opts.extensions = opts.extensions.split(",")
@@ -114,7 +124,8 @@ def run(args=[]):
         mark_not_found_as_absolete=opts.mark_not_found_as_absolete,
         extensions=opts.extensions,
         encoding=opts.encoding,
-        xheaders=opts.xheaders)
+        xheaders=opts.xheaders,
+        include_codeblocks=opts.include_codeblocks)
     if isinstance(opts.wrapwidth, int):
         kwargs['wrapwidth'] = opts.wrapwidth
 
@@ -127,7 +138,7 @@ def run(args=[]):
 
 
 def main():
-    sys.exit(run(args=sys.argv[1:])[1])
+    sys.exit(run(args=sys.argv[1:])[1])  # pragma: no cover
 
 
 if __name__ == '__main__':
