@@ -3,6 +3,7 @@
 import glob
 import html
 import re
+import warnings
 from html.parser import HTMLParser
 
 import md4c
@@ -137,14 +138,18 @@ class MdPo2HTML(HTMLParser):
 
                     raw_html_template += '<%s' % handled
 
-                    attrs_except_href_title = []
+                    # attrs_except_href_title = []
                     for attr, value in attrs:
                         if attr in ['title', 'href']:
                             raw_html_template += ' %s="{}"' % attr
-                        else:
-                            attrs_except_href_title.append(attr)
-                    raw_html_template += html_attrs_tuple_to_string(
-                        attrs_except_href_title) + '>'
+                        # else:
+                        #     These attributes are not included in output
+                        #    attrs_except_href_title.append((attr, value))
+                    # if attrs_except_href_title:
+                    #     raw_html_template += ' '
+                    # raw_html_template += html_attrs_tuple_to_string(
+                    #     attrs_except_href_title) + '>'
+                    raw_html_template += '>'
                 else:
                     raw_html_template += '<%s%s>' % (
                         handled,
@@ -160,10 +165,7 @@ class MdPo2HTML(HTMLParser):
 
                 if all((ch in ALIGNMENT_CHARS) for ch in handled):
                     raw_html_template += handled
-                    if _last_start_tag in self.markup_tags:
-                        _current_replacement += handled
-                    else:
-                        _current_replacement += handled
+                    _current_replacement += handled
                 else:
                     raw_html_template += '{}'
                     if _current_link_target:
@@ -346,6 +348,10 @@ class MdPo2HTML(HTMLParser):
                     self._enable_next_line = True
                 elif command == 'context' and comment:
                     self._current_msgctxt = comment.strip(" ")
+                elif command == 'include-codeblock':
+                    warnings.warn("Code blocks translations is not supported"
+                                  " by mdpo2html implementation.",
+                                  SyntaxWarning)
 
     def translate(self, filepath_or_content, save=None):
         content = to_file_content_if_is_file(filepath_or_content)
@@ -388,6 +394,12 @@ def markdown_pofile_to_html(filepath_or_content, pofiles, ignore=[],
             even if does not exists, will be saved in the path the output of
             the function.
 
+    .. rubric:: Known limitations:
+
+    * This implementation doesn't include support for
+      :ref:`include-codeblock command<include-codeblock-command>`.
+
+
     Returns:
         str: HTML output translated version of the given file.
     """
